@@ -1,3 +1,6 @@
+// Copyright (C) 2013-2015 Kasper Kristensen
+// License: GPL-2
+
 /**	\file
 	\brief Probability distribution functions.
 	*/
@@ -251,7 +254,7 @@ Type dsn(Type x, Type alpha, int give_log=0)
 	// TODO : change pnorm_approx to pnorm when pnorm is written	
 	
 	if(!give_log) return 2 * dnorm(x,Type(0),Type(1),0) * pnorm_approx(alpha*x);
-	else return log(2) + log(dnorm(x,Type(0),Type(1),0)) + log(pnorm_approx(alpha*x));
+	else return log(2.0) + log(dnorm(x,Type(0),Type(1),0)) + log(pnorm_approx(alpha*x));
 }
 
 // Vectorize dsn
